@@ -1,10 +1,10 @@
+# coding: utf-8
+
 """
 Admin ui common utilities.
 """
 
 # PYTHON IMPORTS
-import types
-import warnings
 from fnmatch import fnmatch
 
 # DJANGO IMPORTS
@@ -15,8 +15,8 @@ from django.utils.importlib import import_module
 
 
 def _get_dashboard_cls(dashboard_cls, context):
-    if type(dashboard_cls) is types.DictType:
-        curr_url = context.get('request').META['PATH_INFO']
+    if isinstance(dashboard_cls, dict):
+        curr_url = context.get('request').path
         for key in dashboard_cls:
             admin_site_mod, admin_site_inst = key.rsplit('.', 1)
             admin_site_mod = import_module(admin_site_mod)
@@ -52,7 +52,7 @@ def get_admin_site(context=None, request=None):
         'admin_tools.dashboard.dashboards.DefaultIndexDashboard'
     )
     
-    if type(dashboard_cls) is types.DictType:
+    if isinstance(dashboard_cls, dict):
         if context:
             request = context.get('request')
         curr_url = request.META['PATH_INFO']
@@ -117,7 +117,10 @@ def filter_models(request, models, exclude):
         for item in included:
             model, perms = item
             if fnmatch(full_name(model), pattern):
-                result.remove(item)
+                try:
+                    result.remove(item)
+                except ValueError:  # if the item was already removed skip
+                    pass
     return result
 
 
