@@ -11,8 +11,14 @@ from django.views.decorators.cache import never_cache
 from django.views.generic import View
 from django.utils.translation import ungettext, ugettext as _
 from django.utils.encoding import smart_str
-import django.utils.simplejson as simplejson
 from django.core.exceptions import PermissionDenied
+from django.contrib.admin.util import prepare_lookup_value
+
+# try to use json (2.6+) but stay compatible with 2.5.*
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
 
 # GRAPPELLI IMPORTS
 from grappelli.settings import AUTOCOMPLETE_LIMIT
@@ -25,7 +31,7 @@ def get_label(f):
 
 
 def ajax_response(data):
-    return HttpResponse(simplejson.dumps(data), mimetype='application/javascript')
+    return HttpResponse(json.dumps(data), mimetype='application/javascript')
 
 
 class RelatedLookup(View):
@@ -106,7 +112,7 @@ class AutocompleteLookup(RelatedLookup):
             for item in query_string.split("&"):
                 k, v = item.split("=")
                 if k != "t":
-                    filters[smart_str(k)] = smart_str(v)
+                    filters[smart_str(k)] = prepare_lookup_value(smart_str(k), smart_str(v))
         return qs.filter(**filters)
 
     def get_searched_queryset(self, qs):
@@ -149,4 +155,4 @@ class AutocompleteLookup(RelatedLookup):
             'counter': 0,
         }
         data = [{"value": None, "label": label}]
-        return ajax_response(data)
\ No newline at end of file
+        return ajax_response(data)
